@@ -1,3 +1,3 @@
 '''Training preprocessing modules'''
 from .io import save_tfrecord_data, load_tfrecord_data
-from .processor import TrainingProcessor
+from .processor import TrainingProcessor, TrainingProcessorNorm
